@@ -1,8 +1,4 @@
-use clap::{
-    app_from_crate, crate_authors, crate_description, crate_name, crate_version, AppSettings,
-    SubCommand,
-};
-use itertools::Itertools;
+use clap::{app_from_crate, App, AppSettings};
 
 fn next_workspace_number(conn: &mut swayipc::Connection) -> Result<i32, swayipc::Error> {
     let workspaces = conn.get_workspaces()?;
@@ -11,18 +7,16 @@ fn next_workspace_number(conn: &mut swayipc::Connection) -> Result<i32, swayipc:
     let len = ids.len() as i32;
     Ok(ids
         .into_iter()
-        .tuple_windows()
-        .find(|(cur, next)| cur + 1 != *next)
-        .map_or(len + 1, |(cur, _)| cur + 1))
+        .enumerate()
+        .find(|&(idx, workspace_num)| idx as i32 + 1 != workspace_num)
+        .map_or(len + 1, |(idx, _)| idx as i32 + 1))
 }
 
 fn main() -> Result<(), swayipc::Error> {
     let params = app_from_crate!()
         .about("A command to create new Sway workpaces")
-        .subcommand(SubCommand::with_name("open").about("Open a new workspace"))
-        .subcommand(
-            SubCommand::with_name("move").about("Move the current container to a new workspace"),
-        )
+        .subcommand(App::new("open").about("Open a new workspace"))
+        .subcommand(App::new("move").about("Move the current container to a new workspace"))
         .setting(AppSettings::SubcommandRequired)
         .get_matches();
     let mut conn = swayipc::Connection::new()?;
